@@ -108,61 +108,66 @@ numAgents <- function(N, probInit) {
 #'
 #' # Check that the agents are more often at the higher probability areas based on pr
 #' out <- data.frame(stats::na.omit(crosstab(agentsRas, map)), table(round(map[]))) %>%
-#'    dplyr::mutate(selectionRatio=Freq/Freq.1) %>%
+#'    dplyr::mutate(selectionRatio = Freq/Freq.1) %>%
 #'    dplyr::select(-Var1, -Var1.1) %>%
-#'    dplyr::rename(Present=Freq, Avail=Freq.1, Type=Var2)
+#'    dplyr::rename(Present = Freq, Avail = Freq.1, Type = Var2)
 #'
 setGeneric("initiateAgents",
-          function(map, numAgents, probInit, asSpatialPoints=TRUE, indices) {
+          function(map, numAgents, probInit, asSpatialPoints = TRUE, indices) {
             standardGeneric("initiateAgents")
 })
 
 #' @rdname initiateAgents
-setMethod("initiateAgents",
-          signature=c("Raster", "missing", "missing", "ANY", "missing"),
-          function(map, numAgents, probInit, asSpatialPoints) {
-            initiateAgents(map, indices=1:ncell(map), asSpatialPoints=asSpatialPoints)
+setMethod(
+  "initiateAgents",
+  signature = c("Raster", "missing", "missing", "ANY", "missing"),
+  function(map, numAgents, probInit, asSpatialPoints) {
+    initiateAgents(map, indices = 1:ncell(map), asSpatialPoints = asSpatialPoints)
 })
 
 #' @rdname initiateAgents
-setMethod("initiateAgents",
-          signature=c("Raster", "missing", "Raster", "ANY", "missing"),
-          function(map, probInit, asSpatialPoints) {
-            wh <- which(runif(ncell(probInit)) < getValues(probInit))
-            initiateAgents(map, indices=wh, asSpatialPoints=asSpatialPoints)
+setMethod(
+  "initiateAgents",
+  signature = c("Raster", "missing", "Raster", "ANY", "missing"),
+  function(map, probInit, asSpatialPoints) {
+    wh <- which(runif(ncell(probInit)) < getValues(probInit))
+    initiateAgents(map, indices = wh, asSpatialPoints = asSpatialPoints)
 })
 
 #' @rdname initiateAgents
-setMethod("initiateAgents",
-          signature=c("Raster", "numeric", "missing", "ANY", "missing"),
-          function(map, numAgents, probInit, asSpatialPoints, indices) {
-            wh <- sample(1:ncell(map), size=numAgents, replace=asSpatialPoints)
-            initiateAgents(map, indices=wh, asSpatialPoints=asSpatialPoints)
+setMethod(
+  "initiateAgents",
+  signature = c("Raster", "numeric", "missing", "ANY", "missing"),
+  function(map, numAgents, probInit, asSpatialPoints, indices) {
+    wh <- sample(1:ncell(map), size = numAgents, replace = asSpatialPoints)
+    initiateAgents(map, indices = wh, asSpatialPoints = asSpatialPoints)
 })
 
 #' @rdname initiateAgents
-setMethod("initiateAgents",
-          signature=c("Raster", "numeric", "Raster", "ANY", "missing"),
-          function(map, numAgents, probInit, asSpatialPoints) {
-            vals <- getValues(probInit)
-            wh <- sample(1:ncell(probInit), numAgents, replace=asSpatialPoints,
-                         prob=vals/sum(vals))
-            initiateAgents(map, indices=wh, asSpatialPoints=asSpatialPoints)
+setMethod(
+  "initiateAgents",
+  signature = c("Raster", "numeric", "Raster", "ANY", "missing"),
+  function(map, numAgents, probInit, asSpatialPoints) {
+    vals <- getValues(probInit)
+    wh <- sample(1:ncell(probInit), numAgents, replace = asSpatialPoints,
+                 prob = vals/sum(vals))
+    initiateAgents(map, indices = wh, asSpatialPoints = asSpatialPoints)
 })
 
 #' @rdname initiateAgents
-setMethod("initiateAgents",
-          signature=c("Raster", "missing", "missing", "ANY", "numeric"),
-          function(map, numAgents, probInit, asSpatialPoints, indices) {
-            if(asSpatialPoints) {
-              if(length(indices>0)) {
-                return(xyFromCell(map, indices, spatial=asSpatialPoints))
-              }
-            } else {
-              tmp <- raster(map)
-              tmp[indices] <- 1
-              return(tmp)
-            }
+setMethod(
+  "initiateAgents",
+  signature = c("Raster", "missing", "missing", "ANY", "numeric"),
+  function(map, numAgents, probInit, asSpatialPoints, indices) {
+    if (asSpatialPoints) {
+      if (length(indices > 0)) {
+        return(xyFromCell(map, indices, spatial = asSpatialPoints))
+      }
+    } else {
+      tmp <- raster(map)
+      tmp[indices] <- 1
+      return(tmp)
+    }
 })
 
 ################################################################################
@@ -188,9 +193,9 @@ setMethod("initiateAgents",
 #' @rdname SELESagentLocation
 #' @author Eliot McIntire
 agentLocation <- function(map) {
-    if (length(grep(pattern = "Raster", class(map)))==1) {
-        map[map==0] <- NA
-    } else if (length(grep(pattern = "SpatialPoints", class(map)))==1) {
+    if (length(grep(pattern = "Raster", class(map))) == 1) {
+        map[map == 0] <- NA
+    } else if (length(grep(pattern = "SpatialPoints", class(map))) == 1) {
         map
     } else if (!is.na(pmatch("SpatialPolygons", class(map)))) {
         map
@@ -237,23 +242,24 @@ agentLocation <- function(map) {
 #' @docType methods
 #' @rdname SELESprobInit
 #' @author Eliot McIntire
-probInit = function(map, p=NULL, absolute=NULL) {
-  if(all(inRange(p, 0, 1))) {
-    if(is.null(absolute)) {
+probInit <- function(map, p = NULL, absolute = NULL) {
+  if (all(inRange(p, 0, 1))) {
+    if (is.null(absolute)) {
       absolute <- TRUE
     }
   } else {
     absolute <- FALSE
   }
   if (is.numeric(p)) {
-    probInit <- raster(extent(map), nrows=nrow(map), ncols=ncol(map), crs=crs(map))
-    p <- rep(p, length.out=ncell(map))
-    probInit <- setValues(probInit, p/(sum(p)*(1-absolute)+1*(absolute)))
+    probInit <- raster(extent(map), nrows = nrow(map), ncols = ncol(map),
+                       crs = crs(map))
+    p <- rep(p, length.out = ncell(map))
+    probInit <- setValues(probInit, p/(sum(p)*(1 - absolute) + 1*(absolute)))
 
   } else if (is(p,"RasterLayer")) {
-    probInit = p/(cellStats(p, sum)*(1-absolute)+1*(absolute))
+    probInit <- p/(cellStats(p, sum)*(1 - absolute) + 1*(absolute))
   } else if (is(map,"SpatialPolygonsDataFrame")) {
-    probInit = p/sum(p)
+    probInit <- p/sum(p)
   } else {
     stop("Error initializing probability map: bad inputs")
   }
@@ -265,6 +271,6 @@ probInit = function(map, p=NULL, absolute=NULL) {
 #' @param patches Number of patches.
 #'
 #' @importFrom raster freq
-patchSize = function(patches) {
+patchSize <- function(patches) {
   return(freq(patches))
 }
