@@ -245,10 +245,10 @@ clickCoordinates <- function(n = 1) {
   #npcs <- as.numeric(unlist(strsplit(as.character(gl$heights)[grepNpcsH], "npc") ))
   npcs <- as.character(gl$heights)[grepNpcsH] %>%
     strsplit(., "npc") %>%
-    unlist %>%
-    as.numeric
+    unlist() %>%
+    as.numeric()
   remaining <- 1 - sum(npcs)
-  npcForNulls <- nulls*remaining/sum(nulls)
+  npcForNulls <- nulls * remaining / sum(nulls)
   heightNpcs <- c(npcs, npcForNulls)[order(c(grepNpcsH, grepNullsH))]
 
   clickCoords <- data.frame(x = NA_real_, y = NA_real_, stringsAsFactors = FALSE)
@@ -257,7 +257,7 @@ clickCoordinates <- function(n = 1) {
 
   grobLoc <- list()
 
-  for(i in 1:n) {
+  for (i in 1:n) {
     seekViewport("top")
     gloc <- grid.locator(unit = "npc")
     xInt <- findInterval(as.numeric(strsplit(as.character(gloc$x), "npc")[[1]]),
@@ -266,21 +266,21 @@ clickCoordinates <- function(n = 1) {
     #  as origin... so, require 1-
     yInt <- findInterval(as.numeric(strsplit(as.character(gloc$y), "npc")[[1]]),
                          c(0, cumsum(heightNpcs)))
-    if(!(xInt %in% grepNpcsW) & !(yInt %in% grepNpcsH)) {
+    if (!(xInt %in% grepNpcsW) & !(yInt %in% grepNpcsH)) {
       stop("No plot at those coordinates")
     }
     column <-  which(xInt == grepNpcsW)
     row <- which((yInt == grepNpcsH)[length(grepNpcsH):1])
-    map <- column + (row-1)*arr@arr@columns
+    map <- column + (row - 1) * arr@arr@columns
 
     maxLayX <- cumsum(widthNpcs)[xInt]
-    minLayX <- cumsum(widthNpcs)[xInt-1]
+    minLayX <- cumsum(widthNpcs)[xInt - 1]
     grobLoc$x <- unit((as.numeric(strsplit(
       as.character(gloc$x), "npc"
       )[[1]]) - minLayX) / (maxLayX - minLayX), "npc")
 
     maxLayY <- cumsum(heightNpcs)[yInt]
-    minLayY <- cumsum(heightNpcs)[yInt-1]
+    minLayY <- cumsum(heightNpcs)[yInt - 1]
     grobLoc$y <- unit((as.numeric(strsplit(
       as.character(gloc$y), "npc"
       )[[1]]) - minLayY) / (maxLayY - minLayY), "npc")
@@ -304,10 +304,10 @@ clickCoordinates <- function(n = 1) {
 #' @rdname spadesMouseClicks
 #' @importFrom grid seekViewport grid.locator convertX convertY
 .clickCoord <- function(X, n = 1, gl = NULL) {
-  pts<-data.frame(x = NA_real_, y = NA_real_, stringsAsFactors = FALSE)
+  pts <- data.frame(x = NA_real_, y = NA_real_, stringsAsFactors = FALSE)
   seekViewport(X)
-  for(i in 1:n) {
-    if(is.null(gl)) {
+  for (i in 1:n) {
+    if (is.null(gl)) {
       gl <- grid.locator()
       pts[i, ] <- .unittrim(gl)
     } else {
@@ -317,7 +317,6 @@ clickCoordinates <- function(n = 1) {
   return(pts)
 }
 
-
 ################################################################################
 #' Specify where to plot
 #'
@@ -344,12 +343,12 @@ clickCoordinates <- function(n = 1) {
 #'
 dev <- function(x, ...) {
   if (missing(x)) {
-    if(is.null(dev.list())) {
+    if (is.null(dev.list())) {
       x <- 2L
     } else {
-      if(any(names(dev.list()) == "RStudioGD")) {
-        x <- min(max(dev.list())+1,
-                 which(names(dev.list()) == "RStudioGD")+3L)
+      if (any(names(dev.list()) == "RStudioGD")) {
+        x <- min(max(dev.list()) + 1,
+                 which(names(dev.list()) == "RStudioGD") + 3L)
         dev(x)
       } else {
         x <- max(dev.list())
@@ -357,8 +356,8 @@ dev <- function(x, ...) {
       }
     }
   }
-  if(is.null(dev.list())) newPlot(...)
-  while (dev.set(x)<x) newPlot(...)
+  if (is.null(dev.list())) newPlot(...)
+  while (dev.set(x) < x) newPlot(...)
 }
 
 ################################################################################
