@@ -1,4 +1,9 @@
-stopifnot(packageVersion("SpaDES") >= "1.1.0")
+usesSpaDESVersion <- "1.1.0"
+if(packageVersion("SpaDES") < usesSpaDESVersion) {
+  stop("This randomLandscapes module was built with SpaDES version", usesSpaDESVersion,
+       "Please update SpaDES to use this module")
+}
+rm(usesSpaDESVersion)
 
 defineModule(sim, list(
   name = "randomLandscapes",
@@ -24,7 +29,7 @@ defineModule(sim, list(
     defineParameter("ny", "numeric", 100L, NA, NA, "size of map (number of pixels) in the y dimension"),
     defineParameter("inRAM", "logical", FALSE, NA, NA, "should the raster be stored in memory?"),
     defineParameter(".plotInitialTime", "numeric", 0, NA, NA, "time to schedule first plot event"),
-    defineParameter(".plotInterval", "numeric", NA, NA, NA, "time interval between plot events"),
+    defineParameter(".plotInterval", "numeric", NA_real_, NA, NA, "time interval between plot events"),
     defineParameter(".saveInitialTime", "numeric", NA_real_, NA, NA, "time to schedule first save event"),
     defineParameter(".saveInterval", "numeric", NA_real_, NA, NA, "time interval between save events")
   ),
